InvoiceResult class

Model class representing the result of an invoice calculation.

Constructors

InvoiceResult({required double subtotal, required double discount, required double tax, required double total, required double roundedTotal})
Creates an InvoiceResult instance.

Properties

discount double
The discount amount.
final
hashCode int
The hash code for this object.
no setterinherited
roundedTotal double
The rounded total amount.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtotal double
The subtotal amount.
final
tax double
The tax amount.
final
total double
The total amount.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited