TaxValidators class

A utility class for validating tax related numbers.

Constructors

TaxValidators()
Default constructor.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isValidGstin(String gstin) bool
Validates Indian GSTIN (GST Identification Number)
isValidPan(String pan) bool
Validates Indian PAN card number
isValidTan(String tan) bool
Validates Indian TAN (Tax Deduction Account Number)